emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 72011f2: Fix bug 39218


From: Tino Calancha
Subject: master 72011f2: Fix bug 39218
Date: Thu, 23 Jan 2020 04:59:47 -0500 (EST)

branch: master
commit 72011f23c3135690f65262f01ea92a53ff84b4e1
Author: Tino Calancha <address@hidden>
Commit: Tino Calancha <address@hidden>

    Fix bug 39218
    
    * lisp/simple.el (shell-command):
    Ensure a shell command ending with `&' is run asynchronously.
---
 lisp/simple.el | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/lisp/simple.el b/lisp/simple.el
index f022b84..9bfd58f 100644
--- a/lisp/simple.el
+++ b/lisp/simple.el
@@ -3646,10 +3646,11 @@ impose the use of a shell (with its need to quote 
arguments)."
     (if handler
        (funcall handler 'shell-command command output-buffer error-buffer)
       (if (and output-buffer
+               (not (string-match "[ \t]*&[ \t]*\\'" command))
                (or (eq output-buffer (current-buffer))
                    (and (stringp output-buffer) (eq (get-buffer output-buffer) 
(current-buffer)))
                   (not (or (bufferp output-buffer) (stringp output-buffer))))) 
; Bug#39067
          ;; Output goes in current buffer.
          (let ((error-file
                  (and error-buffer
                       (make-temp-file
@@ -3646,10 +3646,11 @@ impose the use of a shell (with its need to quote 
                   (not (or (bufferp output-buffer) (stringp output-buffer))))) 
; Bug#39067
-         ;; Output goes in current buffer.
+         ;; Synchronous command with output in current buffer.
          (let ((error-file
                  (and error-buffer



reply via email to

[Prev in Thread] Current Thread [Next in Thread]